==> hs-hexpat-0.19.5.tgz: lib/ghc/hexpat-0.19.5/register.sh <==
#!/bin/sh
echo 'name: hexpat
version: 0.19.5
id: hexpat-0.19.5-54083c444025617d89cbeaec8214cdd8

license: BSD3
copyright: (c) 2009 Doug Beardsley <mightybyte@gmail.com>,
           (c) 2009-2010 Stephen Blackheath <http://blacksapphire.com/antispam/>,
           (c) 2009 Gregory Collins,
           (c) 2008 Evan Martin <martine@danga.com>,
           (c) 2009 Matthew Pocock <matthew.pocock@ncl.ac.uk>,
           (c) 2007-2009 Galois Inc.,
           (c) 2010 Kevin Jardine
maintainer: http://blacksapphire.com/antispam/
stability: beta
homepage: http://haskell.org/haskellwiki/Hexpat/
package-url:
description: This package provides a general purpose Haskell XML library using Expat to
             do its parsing (<http://expat.sourceforge.net/> - a fast stream-oriented XML
             parser written in C).  It is extensible to any string type, with @String@,
             @ByteString@ and @Text@ provided out of the box.
             .
             Basic usage: Parsing a tree (/Tree/), formatting a tree (/Format/).
             Other features: Helpers for processing XML trees (/Proc/), trees annotated with
             XML source location (/Annotated/), extended XML trees with comments,
             processing instructions, etc (/Extended/), XML cursors (/Cursor/),
             SAX-style parse (/SAX/), and access to the low-level interface in case speed
             is paramount (/Internal.IO/).
             .
             The design goals are speed, speed, speed, interface simplicity and modularity.
             .
             For introduction and examples, see the /Text.XML.Expat.Tree/ module. For benchmarks,
             <http://haskell.org/haskellwiki/Hexpat/>
             .
             If you want to do interactive I\/O, an obvious option is to use lazy parsing
             with one of the lazy I\/O functions such as hGetContents.  However, this can be
             problematic in some applications because it doesn'\''t handle I\/O errors properly
             and can give no guarantee of timely resource cleanup.  In these cases, chunked
             I\/O is a better approach: Take a look at the /hexpat-iteratee/ package.
             .
             /IO/ is filed under /Internal/ because it'\''s low-level and most users won'\''t want
             it.  The other /Internal/ modules are re-exported by /Annotated/, /Tree/ and /Extended/,
             so you won'\''t need to import them directly.
             .
             Credits to Iavor Diatchki and the @xml@ (XML.Light) package for /Proc/ and /Cursor/.
             Thanks to the many contributors.
             .
             BOUND VS. UNBOUND THREADS: GHC (at least versions 6.12.X) will spawn threads
             if you call a safe FFI callback from an unbound thread.  This can get out of
             control in a busy application.  To avoid this, from version 0.19.1 we now delegate
             processing to a single worker thread if the calling thread is not bound.
             This essentially means that hexpat currently won'\''t exploit multicores very well.
             It also means that hexpat may be more efficient on threads spawned with forkOS
             (to give you a bound thread) rather than forkIO.
             .
             ChangeLog: 0.15 changes intended to fix a (rare) \"error: a C finalizer called back into Haskell.\"
             that seemed only to happen only on ghc6.12.X; 0.15.1 Fix broken Annotated parse;
             0.16 switch from mtl to transformers; 0.17 fix mapNodeContainer & rename some things.;
             0.18 rename defaultEncoding to overrideEncoding. 0.18.3 formatG and indent were demanding list
             items more than once (inefficient in chunked processing); 0.19 add Extended.hs;
             0.19.1 fix a memory leak introduced in 0.19, delegate parsing to bound thread
             if unbound (see note above); 0.19.2 include expat source code so \'\''cabal install\'\'' just works
             on Linux, Mac and Windows (thanks Jacob Stanley); 0.19.3 fix misconfiguration of expat
             which broke entity parsing; 0.19.4 bump version constraint for text; 0.19.5 bump text
             to < 0.12 and fix text-0.10.0.1 breakage.
category: XML
author: Stephen Blackheath [blackh] (the primary author),
        Doug Beardsley,
        Gregory Collins,
        Evan Martin (who started the project),
        Matthew Pocock [drdozer],
        Kevin Jardine,
        Jacob Stanley
pkgpath: textproc/hs-hexpat
exposed: True
exposed-modules: Text.XML.Expat.Annotated Text.XML.Expat.Cursor
                 Text.XML.Expat.Extended Text.XML.Expat.Format Text.XML.Expat.IO
                 Text.XML.Expat.Namespaced Text.XML.Expat.NodeClass
                 Text.XML.Expat.Proc Text.XML.Expat.Qualified Text.XML.Expat.SAX
                 Text.XML.Expat.Tree Text.XML.Expat.Internal.DocumentClass
                 Text.XML.Expat.Internal.IO Text.XML.Expat.Internal.Namespaced
                 Text.XML.Expat.Internal.NodeClass Text.XML.Expat.Internal.Qualified
hidden-modules:
import-dirs: /usr/local/lib/ghc/hexpat-0.19.5
library-dirs: /usr/local/lib/ghc/hexpat-0.19.5
hs-libraries: HShexpat-0.19.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: List-0.4.0-ffc85b7b4dab83f774cc96501795c8b5
         base-4.2.0.2-af431bb15643ef1ce2792a51c33968b3
         bytestring-0.9.1.7-352f069cca85cb3f9e4c06bb76ec4cec
         containers-0.3.0.0-7be04792060ce1514c52e2cb13a5c18a
         deepseq-1.1.0.0-bdee49850bb3a374a352be0c188f0973
         extensible-exceptions-0.1.1.1-28a83091e117b2e719d4a1c4a320a1c8
         text-0.10.0.2-3cd9f1eb0231de4ddb5f61b812f95036
         transformers-0.2.1.0-83bd04c7d756a68d4480a7c48ea90dcc
         utf8-string-0.3.6-5ee26357cb5966310fb19966a1a80ed8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hexpat-0.19.5/html/hexpat.haddock
haddock-html: /usr/local/share/doc/hs-hexpat-0.19.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-hexpat-0.19.10p2.tgz: lib/ghc/hexpat-0.19.10/register.sh <==
#!/bin/sh
echo 'name: hexpat
version: 0.19.10
id: hexpat-0.19.10-2ba7df58c7a8ac7d36a08a6f154e93f5

license: BSD3
copyright: (c) 2009 Doug Beardsley <mightybyte@gmail.com>,
           (c) 2009-2012 Stephen Blackheath <http://blacksapphire.com/antispam/>,
           (c) 2009 Gregory Collins,
           (c) 2008 Evan Martin <martine@danga.com>,
           (c) 2009 Matthew Pocock <matthew.pocock@ncl.ac.uk>,
           (c) 2007-2009 Galois Inc.,
           (c) 2010 Kevin Jardine,
           (c) 2012 Simon Hengel
maintainer: http://blacksapphire.com/antispam/
stability: beta
homepage: http://haskell.org/haskellwiki/Hexpat/
package-url:
synopsis: XML parser/formatter based on expat
description: This package provides a general purpose Haskell XML library using Expat to
             do its parsing (<http://expat.sourceforge.net/> - a fast stream-oriented XML
             parser written in C).  It is extensible to any string type, with @String@,
             @ByteString@ and @Text@ provided out of the box.
             .
             Basic usage: Parsing a tree (/Tree/), formatting a tree (/Format/).
             Other features: Helpers for processing XML trees (/Proc/), trees annotated with
             XML source location (/Annotated/), extended XML trees with comments,
             processing instructions, etc (/Extended/), XML cursors (/Cursor/),
             SAX-style parse (/SAX/), and access to the low-level interface in case speed
             is paramount (/Internal.IO/).
             .
             The design goals are speed, speed, speed, interface simplicity and modularity.
             .
             For introduction and examples, see the /Text.XML.Expat.Tree/ module. For benchmarks,
             <http://haskell.org/haskellwiki/Hexpat/>
             .
             If you want to do interactive I\/O, an obvious option is to use lazy parsing
             with one of the lazy I\/O functions such as hGetContents.  However, this can be
             problematic in some applications because it doesn'\''t handle I\/O errors properly
             and can give no guarantee of timely resource cleanup.  In these cases, chunked
             I\/O is a better approach: Take a look at the /hexpat-enumerator/ package.
             .
             /IO/ is filed under /Internal/ because it'\''s low-level and most users won'\''t want
             it.  The other /Internal/ modules are re-exported by /Annotated/, /Tree/ and /Extended/,
             so you won'\''t need to import them directly.
             .
             Credits to Iavor Diatchki and the @xml@ (XML.Light) package for /Proc/ and /Cursor/.
             Thanks to the many contributors.
             .
             BOUND VS. UNBOUND THREADS: GHC (at least versions 6.12.X) will spawn threads
             if you call a safe FFI callback from an unbound thread.  This can get out of
             control in a busy application.  To avoid this, from version 0.19.1 we now delegate
             processing to a single worker thread if the calling thread is not bound.
             This essentially means that hexpat currently won'\''t exploit multicores very well.
             It also means that hexpat may be more efficient on threads spawned with forkOS
             (to give you a bound thread) rather than forkIO.
             .
             ChangeLog: 0.15 changes intended to fix a (rare) \"error: a C finalizer called back into Haskell.\"
             that seemed only to happen only on ghc6.12.X; 0.15.1 Fix broken Annotated parse;
             0.16 switch from mtl to transformers; 0.17 fix mapNodeContainer & rename some things.;
             0.18 rename defaultEncoding to overrideEncoding. 0.18.3 formatG and indent were demanding list
             items more than once (inefficient in chunked processing); 0.19 add Extended.hs;
             0.19.1 fix a memory leak introduced in 0.19, delegate parsing to bound thread
             if unbound (see note above); 0.19.2 include expat source code so \'\''cabal install\'\'' just works
             on Linux, Mac and Windows (thanks Jacob Stanley); 0.19.3 fix misconfiguration of expat
             which broke entity parsing; 0.19.4 bump version constraint for text; 0.19.5 bump text
             to < 0.12 and fix text-0.10.0.1 breakage; 0.19.6 dependency breakage with List;
             0.19.7 ghc-7.2.1 compatibility; 0.19.8 fix space leak on lazy parse under ghc-7.2.1;
             0.19.9 fix formatting of > character + improve performance; 0.9.10 ghc-7.4.x compatibility.
category: XML
author: Stephen Blackheath [blackh] (the primary author),
        Doug Beardsley,
        Gregory Collins,
        Evan Martin (who started the project),
        Matthew Pocock [drdozer],
        Kevin Jardine,
        Jacob Stanley,
        Simon Hengel
pkgpath: textproc/hs-hexpat
exposed: True
exposed-modules: Text.XML.Expat.Annotated Text.XML.Expat.Cursor
                 Text.XML.Expat.Extended Text.XML.Expat.Format Text.XML.Expat.IO
                 Text.XML.Expat.Namespaced Text.XML.Expat.NodeClass
                 Text.XML.Expat.Proc Text.XML.Expat.Qualified Text.XML.Expat.SAX
                 Text.XML.Expat.Tree Text.XML.Expat.Internal.DocumentClass
                 Text.XML.Expat.Internal.IO Text.XML.Expat.Internal.Namespaced
                 Text.XML.Expat.Internal.NodeClass Text.XML.Expat.Internal.Qualified
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/hexpat-0.19.10
library-dirs: /usr/local/lib/ghc/hexpat-0.19.10
hs-libraries: HShexpat-0.19.10
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: List-0.4.2-bba8a5b096e448da7234a0d2bff22242
         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
         extensible-exceptions-0.1.1.4-255a395b3b026cb94b23754e1c372785
         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
         utf8-string-0.3.8-4b98c0faca0296b4da4f390d8a63aa83
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-hexpat-0.19.10/html/hexpat.haddock
haddock-html: /usr/local/share/doc/hs-hexpat-0.19.10/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
